@@ -222,6 +222,8 @@ class fillVars(varsShare):
                     mapUuidDev = dict(map(lambda x:(path.basename(x),
                                     path.normpath(path.join(uuidpath,
                                     os.readlink(x)))), uuidDevs))
+                else:
+                    mapUuidDev = {}
                 if re.match("^UUID=.*$",rootparam):
                     uuid = rootparam[5:]
                     if uuid in mapUuidDev:
