@@ -599,8 +599,8 @@ def isFstabMount(pathname,mapDevUuid={}):
         absPath = "swap"
     else:
         absPath = os.path.abspath(pathname)
-    if not mapDevUuid:
-        devuuid = '/dev/disk/by-uuid'
+    devuuid = '/dev/disk/by-uuid'
+    if not mapDevUuid and os.path.exists(devuuid):
         mapDevUuid.update(
             map(lambda x:("UUID=%s"%os.path.basename(x),
                     os.path.normpath(os.path.join(devuuid,os.readlink(x)))),
